@@ -108,6 +108,7 @@ impl Core {
                         SystemMsg::AntiEntropyRetry { .. }
                         | SystemMsg::AntiEntropyUpdate { .. }
                         | SystemMsg::AntiEntropyRedirect { .. }
+                        | SystemMsg::AntiEntropyProbe(_)
                         | SystemMsg::JoinRequest(_)
                         | SystemMsg::JoinAsRelocatedRequest(_) => {}
                         _ => match dst_location.section_pk() {
@@ -266,7 +267,7 @@ impl Core {
         }
     }
 
-    // Hanlder for node messages which have successfully
+    // Handler for node messages which have successfully
     // passed all signature checks and msg verifications
     pub(crate) async fn handle_verified_non_data_node_message(
         &mut self,
@@ -327,6 +328,10 @@ impl Core {
                 )
                 .await
             }
+            SystemMsg::AntiEntropyProbe(_dst) => {
+                info!("Received Probe message from {:?}: {:?}", sender, msg_id);
+                Ok(vec![])
+            }
             SystemMsg::Relocate(ref details) => {
                 trace!("Handling msg: Relocate from {}", sender);
                 if let NodeMsgAuthority::Section(section_signed) = msg_authority {
